@@ -6,7 +6,7 @@ from evdev import ecodes
 default_handler = EventHandler('default-handler')
 
 def default_handler_wrap(name):
-    'Return a callable that relays calls to a default handler.'
+    '''Return a callable that relays calls to the default handler.'''
 
     # @functools.wraps(getattr(default_handler, name))
     def wrapper(*args, **kw):
